# Reset and pause abci

## Description

This module contains the ABCI reset and pause skill for an AEA. It implements an ABCI
application.

## Behaviours

* `ResetAndPauseBehaviour`

   Reset state.

* `ResetPauseABCIConsensusBehaviour`

   This behaviour manages the consensus stages for the reset and pause abci app.

## Handlers

* `ResetPauseABCIHandler`
* `HttpHandler`
* `SigningHandler`

